@@ -21,12 +21,12 @@
 #include <RcppArmadillo.h>
 #define NDEBUG
 #include <cppbugs/mcmc.deterministic.hpp>
-#include <cppbugs/mcmc.normal.hpp>
-#include <cppbugs/mcmc.uniform.hpp>
-#include <cppbugs/mcmc.gamma.hpp>
-#include <cppbugs/mcmc.beta.hpp>
-#include <cppbugs/mcmc.binomial.hpp>
-#include <cppbugs/mcmc.bernoulli.hpp>
+#include <cppbugs/distributions/mcmc.normal.hpp>
+#include <cppbugs/distributions/mcmc.uniform.hpp>
+#include <cppbugs/distributions/mcmc.gamma.hpp>
+#include <cppbugs/distributions/mcmc.beta.hpp>
+#include <cppbugs/distributions/mcmc.binomial.hpp>
+#include <cppbugs/distributions/mcmc.bernoulli.hpp>
 
 #include "helpers.h"
 #include "raw.address.h"
@@ -71,6 +71,13 @@ void initArgList(SEXP args, arglistT& arglist, const size_t skip);
 SEXP makeNames(std::vector<const char*>& argnames);
 SEXP createTrace(arglistT& arglist, vpArmaMapT& armaMap, vpMCMCMapT& mcmcMap);
 
+template<typename T>
+void releaseMap(T& m) {
+  for (typename T::iterator it=m.begin(); it != m.end(); it++) {
+    delete it->second;
+  }
+}
+
 void initArgList(SEXP args, arglistT& arglist, const size_t skip) {
 
   for(size_t i = 0; i < skip; i++) {
@@ -110,10 +117,10 @@ SEXP logp(SEXP x_, SEXP rho_) {
 
   try {
     x_ = forceEval(x_, rho_, eval_limit);
-    ArmaContext* ap = getArma(x_);
-    armaMap[rawAddress(x_)] = ap;
+    ArmaContext* ap = mapOrFetch(x_, armaMap);
     node = createMCMC(x_,armaMap);
   } catch (std::logic_error &e) {
+    releaseMap(armaMap); UNPROTECT(armaMap.size());
     REprintf("%s\n",e.what());
     return R_NilValue;
   }
@@ -124,6 +131,7 @@ SEXP logp(SEXP x_, SEXP rho_) {
   } else {
     REprintf("ERROR: could not convert node to stochastic.\n");
   }
+  releaseMap(armaMap); UNPROTECT(armaMap.size());
   return Rcpp::wrap(ans);
 }
 
@@ -204,13 +212,6 @@ SEXP makeNames(std::vector<const char*>& argnames) {
   return ans;
 }
 
-template<typename T>
-void releaseMap(T& m) {
-  for (typename T::iterator it=m.begin(); it != m.end(); it++) {
-    delete it->second;
-  }
-}
-
 SEXP createTrace(arglistT& arglist, vpArmaMapT& armaMap, vpMCMCMapT& mcmcMap) {
   SEXP ans; PROTECT(ans = Rf_allocVector(VECSXP, arglist.size()));
   for(size_t i = 0; i < arglist.size(); i++) {
